Backends
========

.. automodule:: urllib3.backend

.. autoclass:: urllib3.backend.BaseBackend
    :members:
    :show-inheritance:

.. autoclass:: urllib3.backend.hface.HfaceBackend
    :members:
    :show-inheritance:

.. autoclass:: urllib3.backend.HttpVersion
    :members:

.. autoclass:: urllib3.backend.ResponsePromise
    :members:

.. autoclass:: urllib3.backend.QuicPreemptiveCacheType

.. autoclass:: urllib3.backend.ConnectionInfo
    :members:
